@@ -1,5 +1,5 @@
 #-------------------------------------------------------------------------------
-# $Id: models.py 1550 2012-03-20 16:03:26Z schindlerf $
+# $Id: models.py 2147 2012-11-28 11:17:33Z schindlerf $
 #
 # Project: EOxServer <http://eoxserver.org>
 # Authors: Stephan Krause <stephan.krause@eox.at>
@@ -325,7 +325,7 @@ class EODatasetMixIn(EOCoverageMixIn):
     
     def delete(self):
         data_package = self.data_package
-        super(EOCoverageMixIn, self).delete()
+        super(EODatasetMixIn, self).delete()
         data_package.delete()
         
 class RectifiedDatasetRecord(CoverageRecord, EODatasetMixIn):
@@ -361,7 +361,7 @@ class RectifiedDatasetRecord(CoverageRecord, EODatasetMixIn):
     
     def delete(self):
         extent = self.extent
-        super(EOCoverageMixIn, self).delete()
+        super(RectifiedDatasetRecord, self).delete()
         extent.delete()
 
 class ReferenceableDatasetRecord(CoverageRecord, EODatasetMixIn):
